if(POLICY CMP0079)
    cmake_policy(SET CMP0079 NEW)
endif()

function(add_ps3_build_steps)
    link_libraries(stdc++ simdmath rsx gcm_sys io audio sysutil rt lv2 m)

    setup_ps3_pkg()
endfunction()

# Setup PS3 Package Generation
function(setup_ps3_pkg)
    psl1ght_pkg_step1()
    psl1ght_pkg_step2()
    psl1ght_pkg_step3()

    add_dependencies(${BINARY_NAME}_pkg ${BINARY_NAME}_ps3_pkg_step3)
endfunction()

# This function makes the staging directory, copies the icon into it, makes the .self into a npdrm self (EBOOT.BIN) and generates the PARAM.SFO
function(psl1ght_pkg_step1)
    add_custom_target(${BINARY_NAME}_pkg ALL DEPENDS ${BINARY_NAME}-sdl)

    configure_file(${CMAKE_CURRENT_SOURCE_DIR}/sfo.xml ${CMAKE_BINARY_DIR}/sfo.xml)

    add_custom_target(${BINARY_NAME}_ps3_pkg_step1)
    add_custom_command(
        TARGET ${BINARY_NAME}_ps3_pkg_step1
        COMMENT "Running initial PKG setup"
        COMMAND mkdir -p ${CMAKE_BINARY_DIR}/${BINARY_NAME}_pkg/USRDIR # Make the staging directory
        COMMAND cp ${PS3_PKG_ICON} ${CMAKE_BINARY_DIR}/${BINARY_NAME}_pkg/ICON0.PNG # Copy the icon into the staging directory
        COMMAND ${PS3DEV}/bin/make_self_npdrm "$<TARGET_FILE:${BINARY_NAME}-sdl>" "${CMAKE_BINARY_DIR}/${BINARY_NAME}_pkg/USRDIR/EBOOT.BIN" ${PS3_PKG_CONTENT_ID} # Make the MNDRM self file
        COMMAND ${PS3DEV}/bin/sfo.py --title "${PS3_PKG_TITLE}" --appid "${PS3_PKG_TITLE_ID}" -f "${CMAKE_BINARY_DIR}/sfo.xml" ${CMAKE_BINARY_DIR}/${BINARY_NAME}_pkg/PARAM.SFO # Generate the PARAM.SFO from the given sfo.xml file
    )
endfunction()

# This function just adds a custom command to copy content from a specific folder (the 2nd parameter) to the pkg staging folder
function(psl1ght_pkg_step2)
    add_custom_target(${BINARY_NAME}_ps3_pkg_step2 DEPENDS ${BINARY_NAME}_ps3_pkg_step1)
    add_custom_command(
        TARGET ${BINARY_NAME}_ps3_pkg_step2
        COMMENT "Adding content files"
        COMMAND cp -r ${CMAKE_SOURCE_DIR}/${PS3_PKG_CONTENT_FOLDER}/* ${CMAKE_BINARY_DIR}/${BINARY_NAME}_pkg/ # Copy the content into the staging directory
    )
endfunction()

# This function builds the PKG before finalizing it for gnpdrm
function(psl1ght_pkg_step3)
    file(GLOB RESULT "${CMAKE_SOURCE_DIR}/${PS3_PKG_CONTENT_FOLDER}/*")
    list(LENGTH RESULT RES_LEN)
    if(${RES_LEN} EQUAL 0)
        # no content
        add_custom_target(${BINARY_NAME}_ps3_pkg_step3 DEPENDS ${BINARY_NAME}_ps3_pkg_step1)
    else()
        # has content
        add_custom_target(${BINARY_NAME}_ps3_pkg_step3 DEPENDS ${BINARY_NAME}_ps3_pkg_step2)
    endif()

    add_custom_command(
        TARGET ${BINARY_NAME}_ps3_pkg_step3
        COMMENT "Finalizing PKG build"
        COMMAND ${PS3DEV}/bin/pkg.py --contentid ${PS3_PKG_CONTENT_ID} ${CMAKE_BINARY_DIR}/${BINARY_NAME}_pkg/ ${CMAKE_BINARY_DIR}/${BINARY_NAME}.pkg # Create the PKG file
        COMMAND cp ${CMAKE_BINARY_DIR}/${BINARY_NAME}.pkg ${CMAKE_BINARY_DIR}/${BINARY_NAME}.gnpdrm.pkg # Copy that PKG file to a new PKG file for finalization
        COMMAND ${PS3DEV}/bin/package_finalize ${CMAKE_BINARY_DIR}/${BINARY_NAME}.gnpdrm.pkg # Finalize that PKG file to get a GNPDRM PKG
    )
endfunction()
